<?php
/**
 * Customizer active callbacks
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */


/**
 * Check if loader is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_loader_enable( $control ) {
	return $control->manager->get_setting( 'business_center_pro_theme_options[loader_enable]' )->value();
}

/**
 * Check if breadcrumb is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_breadcrumb_enable( $control ) {
	return $control->manager->get_setting( 'business_center_pro_theme_options[breadcrumb_enable]' )->value();
}


/**
 * Check if pagination is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function business_center_pro_is_pagination_enable( $control ) {
	return $control->manager->get_setting( 'business_center_pro_theme_options[pagination_enable]' )->value();
}

/**
 * Check if slider is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_slider_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_slider]' )->value() )
		return true;

	return false;
}

/**
 * Check if opacity type custom is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_opacity_type_custom( $control ) {
	$opacity_type = $control->manager->get_setting( 'business_center_pro_theme_options[slider_overlay]' )->value();
	if ( business_center_pro_is_slider_enable( $control ) && 'custom' == $opacity_type )
		return true;

	return false;
}


/**
 * Check if content type demo is disabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_slider_demo_disable( $control ) {
	$slider_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[slider_content_type]' )->value();
	if ( business_center_pro_is_slider_enable( $control ) && 'demo' != $slider_content_type )
		return true;

	return false;
}


/**
 * Check if content type page is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_slider_content_type_page_enable( $control ) {
	$slider_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[slider_content_type]' )->value();
	if ( business_center_pro_is_slider_enable( $control ) && 'page' == $slider_content_type )
		return true;

	return false;
}


/**
 * Check if content type category is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_slider_content_type_category_enable( $control ) {
	$slider_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[slider_content_type]' )->value();
	if ( business_center_pro_is_slider_enable( $control ) && 'category' == $slider_content_type )
		return true;

	return false;
}


/**
 * Check if content type custom is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_slider_content_type_custom_enable( $control ) {
	$slider_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[slider_content_type]' )->value();
	if ( business_center_pro_is_slider_enable( $control ) && 'custom' == $slider_content_type )
		return true;

	return false;
}


/**
 * Check if service is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_service_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_service]' )->value() )
		return true;

	return false;
}

/**
 * Check if services content type demo is disabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_service_demo_disable( $control ) {
	$service_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[service_content_type]' )->value();
	if ( business_center_pro_is_service_enable( $control ) && 'demo' != $service_content_type )
		return true;

	return false;
}

/**
 * Check if content type custom is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_service_content_type_custom_enable( $control ) {
	$service_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[service_content_type]' )->value();
	if ( business_center_pro_is_service_enable( $control ) && 'custom' == $service_content_type )
		return true;

	return false;
}

/**
 * Check if content type category is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_service_content_type_category_enable( $control ) {
	$service_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[service_content_type]' )->value();
	if ( business_center_pro_is_service_enable( $control ) && 'category' == $service_content_type )
		return true;

	return false;
}

/**
 * Check if content type service is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_service_content_type_service_enable( $control ) {
	$service_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[service_content_type]' )->value();
	if ( business_center_pro_is_service_enable( $control ) && 'service' == $service_content_type )
		return true;

	return false;
}

/**
 * Check if content type category is either custom or category.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_service_content_type_category_or_custom_enable( $control ) {
	$service_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[service_content_type]' )->value();
	if ( business_center_pro_is_service_content_type_category_enable( $control ) || 'custom' == $service_content_type )
		return true;

	return false;
}

/**
 * Check if feature is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_feature_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_feature]' )->value() )
		return true;

	return false;
}

/**
 * Check if content type demo is disabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_feature_demo_disable( $control ) {
	$feature_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[feature_content_type]' )->value();
	if ( business_center_pro_is_feature_enable( $control ) && 'demo' != $feature_content_type )
		return true;

	return false;
}


/**
 * Check if content type custom is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_feature_content_type_custom_enable( $control ) {
	$feature_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[feature_content_type]' )->value();
	if ( business_center_pro_is_feature_enable( $control ) && 'custom' == $feature_content_type )
		return true;

	return false;
}

/**
 * Check if icon type fa icon is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_feature_content_type_custom_fa_icon_enable( $control ) {
	$feature_icon_type = $control->manager->get_setting( 'business_center_pro_theme_options[feature_icon_type]' )->value();
	if ( business_center_pro_is_feature_content_type_custom_category_enable( $control ) && 'fa-icon' == $feature_icon_type )
		return true;

	return false;
}

/**
 * Check if content type custom and category is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_feature_content_type_custom_category_enable( $control ) {
	$feature_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[feature_content_type]' )->value();
	if ( business_center_pro_is_feature_enable( $control ) && ( 'custom' == $feature_content_type || 'category' == $feature_content_type ) )
		return true;

	return false;
}

/**
 * Check if content type custom is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_feature_content_type_custom_image_icon_enable( $control ) {
	$feature_icon_type = $control->manager->get_setting( 'business_center_pro_theme_options[feature_icon_type]' )->value();
	if ( business_center_pro_is_feature_content_type_custom_category_enable( $control ) && 'img-icon' == $feature_icon_type )
		return true;

	return false;
}


/**
 * Check if content type category is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_feature_content_type_category_enable( $control ) {
	$feature_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[feature_content_type]' )->value();
	if ( business_center_pro_is_feature_enable( $control ) && 'category' == $feature_content_type )
		return true;

	return false;
}

/**
 * Check if testimonial is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_testimonial_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_testimonial]' )->value() )
		return true;

	return false;
}

/**
 * Check if content type demo is disabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_testimonial_demo_disable( $control ) {
	$testimonial_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[testimonial_content_type]' )->value();
	if ( business_center_pro_is_testimonial_enable( $control ) && 'demo' != $testimonial_content_type )
		return true;

	return false;
}

/**
 * Check if content type custom is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_testimonial_content_type_custom_enable( $control ) {
	$testimonial_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[testimonial_content_type]' )->value();
	if ( business_center_pro_is_testimonial_enable( $control ) && 'custom' == $testimonial_content_type )
		return true;

	return false;
}

/**
 * Check if content type category is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_testimonial_content_type_category_enable( $control ) {
	$testimonial_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[testimonial_content_type]' )->value();
	if ( business_center_pro_is_testimonial_enable( $control ) && 'category' == $testimonial_content_type )
		return true;

	return false;
}

/**
 * Check if portfolio is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_portfolio_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_portfolio]' )->value() )
		return true;

	return false;
}

/**
 * Check if content type demo is disabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_portfolio_demo_disable( $control ) {
	$portfolio_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[portfolio_content_type]' )->value();
	if ( business_center_pro_is_portfolio_enable( $control ) && 'demo' != $portfolio_content_type )
		return true;

	return false;
}

/**
 * Check if content type custom is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_portfolio_content_type_custom_enable( $control ) {
	$portfolio_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[portfolio_content_type]' )->value();
	if ( business_center_pro_is_portfolio_enable( $control ) && 'custom' == $portfolio_content_type )
		return true;

	return false;
}

/**
 * Check if content type category is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_portfolio_content_type_category_enable( $control ) {
	$portfolio_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[portfolio_content_type]' )->value();
	if ( business_center_pro_is_portfolio_enable( $control ) && 'category' == $portfolio_content_type )
		return true;

	return false;
}

/**
 * Check if call to action is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_call_to_action_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_call_to_action]' )->value() )
		return true;

	return false;
}

/**
 * Check if content type demo is disabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_call_to_action_demo_disable( $control ) {
	$call_to_action_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[call_to_action_content_type]' )->value();
	if ( business_center_pro_is_call_to_action_enable( $control ) && 'demo' != $call_to_action_content_type )
		return true;

	return false;
}

/**
 * Check if content type custom is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_call_to_action_content_type_custom_enable( $control ) {
	$call_to_action_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[call_to_action_content_type]' )->value();
	if ( business_center_pro_is_call_to_action_enable( $control ) && 'custom' == $call_to_action_content_type )
		return true;

	return false;
}

/**
 * Check if content type post is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_call_to_action_content_type_post_enable( $control ) {
	$call_to_action_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[call_to_action_content_type]' )->value();
	if ( business_center_pro_is_call_to_action_enable( $control ) && 'post' == $call_to_action_content_type )
		return true;

	return false;
}

/**
 * Check if pricing is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_pricing_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_pricing]' )->value() )
		return true;

	return false;
}

/**
 * Check if content type demo is disabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_pricing_demo_disable( $control ) {
	$pricing_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[pricing_content_type]' )->value();
	if ( business_center_pro_is_pricing_enable( $control ) && 'demo' != $pricing_content_type )
		return true;

	return false;
}

/**
 * Check if content type custom is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_pricing_content_type_custom_enable( $control ) {
	$pricing_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[pricing_content_type]' )->value();
	if ( business_center_pro_is_pricing_enable( $control ) && 'custom' == $pricing_content_type )
		return true;

	return false;
}

/**
 * Check if content type category is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_pricing_content_type_category_enable( $control ) {
	$pricing_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[pricing_content_type]' )->value();
	if ( business_center_pro_is_pricing_enable( $control ) && 'category' == $pricing_content_type )
		return true;

	return false;
}

/**
 * Check if content type custom and category is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_pricing_content_type_custom_category_enable( $control ) {
	if ( business_center_pro_is_pricing_content_type_category_enable( $control ) || business_center_pro_is_pricing_content_type_custom_enable( $control ) )
		return true;

	return false;
}

/**
 * Check if front page blog is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_front_page_blog_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_front_page_blog]' )->value() )
		return true;

	return false;
}

/**
 * Check if content type demo is disabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_front_page_blog_demo_disable( $control ) {
	$front_page_blog_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[front_page_blog_content_type]' )->value();
	if ( business_center_pro_is_front_page_blog_enable( $control ) && 'demo' != $front_page_blog_content_type )
		return true;

	return false;
}

/**
 * Check if team is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_team_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_team]' )->value() )
		return true;

	return false;
}

/**
 * Check if content type demo is disabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_team_demo_disable( $control ) {
	$team_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[team_content_type]' )->value();
	if ( business_center_pro_is_team_enable( $control ) && 'demo' != $team_content_type )
		return true;

	return false;
}

/**
 * Check if content type custom is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_team_content_type_custom_enable( $control ) {
	$team_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[team_content_type]' )->value();
	if ( business_center_pro_is_team_enable( $control ) && 'custom' == $team_content_type )
		return true;

	return false;
}

/**
 * Check if content type category is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_team_content_type_category_enable( $control ) {
	$team_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[team_content_type]' )->value();
	if ( business_center_pro_is_team_enable( $control ) && 'category' == $team_content_type )
		return true;

	return false;
}

/**
 * Check if skill is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_skill_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_skill]' )->value() )
		return true;

	return false;
}

/**
 * Check if content type demo is disabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_skill_demo_disable( $control ) {
	$skill_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[skill_content_type]' )->value();
	if ( business_center_pro_is_skill_enable( $control ) && 'demo' != $skill_content_type )
		return true;

	return false;
}

/**
 * Check if content type custom is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_skill_content_type_custom_enable( $control ) {
	$skill_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[skill_content_type]' )->value();
	if ( business_center_pro_is_skill_enable( $control ) && 'custom' == $skill_content_type )
		return true;

	return false;
}

/**
 * Check if client is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_client_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_client]' )->value() )
		return true;

	return false;
}

/**
 * Check if content type demo is disabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_client_demo_disable( $control ) {
	$client_content_type = $control->manager->get_setting( 'business_center_pro_theme_options[client_content_type]' )->value();
	if ( business_center_pro_is_client_enable( $control ) && 'demo' != $client_content_type )
		return true;

	return false;
}

/**
 * Check if contact is enabled.
 *
 * @since Business Center Pro 2.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function business_center_pro_is_contact_enable( $control ) {
	if ( $control->manager->get_setting( 'business_center_pro_theme_options[enable_contact]' )->value() )
		return true;

	return false;
}