<?php
/**
 * Business Center Pro customizer default options
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */


/**
 * Returns the default options for Business Center Pro.
 *
 * @since Business Center Pro 2.0.0
 * @return array An array of default values
 */
function business_center_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	
	$business_center_pro_default_options = array(
		// Additional menu options
		'append_search'                               => true,
		'make_menu_sticky'                            => true,
		'menu_position'								  => 'mobile-menu',
		
		// Color layout options
		'color_layout'                                => '#FDD947',
		
		// Theme Options
		'theme_typography'                            => 'default',
		'loader_enable'                               => false,
		'loader_icon'                                 => 'fa-spinner',
		'site_layout'                                 => 'wide',
		'sidebar_position'                            => 'right-sidebar',
		'excerpt_length'                              => 50,
		'read_more_text'                              => esc_html__( 'Read More', 'business-center-pro' ),
		'breadcrumb_enable'                           => false,
		'breadcrumb_show_on_front'                    => true,
		'breadcrumb_title'                            => esc_html__( 'Browse', 'business-center-pro' ),
		'pagination_enable'                           => true,
		'pagination_type'                             => 'default',
		'pagination_enable'                           => true,
		'hide_date'                                   => false,
		'hide_author'                                 => false,
		'hide_tags'                                   => false,
		'hide_category'                               => false,
		'hide_featured_image'                         => false,
		'reset_options'                               => false,
		'enable_frontpage_content'                    => true,
		'archive_grid_layout'                         => 'grid',
		'blog_layout'                                 => 'three',
		'blog_content_type'                           => 'excerpt',
		
		//Footer Editor Options
		'copyright_text'                              => sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved.', '1: Year, 2: Site Title with home URL', 'business-center-pro' ), '[the-year]', '[site-link]' ),
		'powered_by'                          =>  esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'business-center-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( $theme_data->get( 'Author' ) ) .'</a>',
		'scroll_top_visible'                          => true,
		
		/**
		* Sections options
		*/
		// Slider
		'enable_slider'                               => true,
		'slider_transition'                           => 'cubic-bezier(0.250, 0.100, 0.250, 1.000)',
		'slider_overlay'                              => 'custom',
		'opacity_value'                               => 0.3,
		'slider_content_type'                         => 'demo',
		'enable_slider_controls'                      => true,
		'enable_slider_pager'                         => true,
		'enable_slider_autoplay'                      => true,
		'enable_slider_caption'                       => true,
		'make_slider_draggable'                       => false,
		'slider_scroll_down_id'                       => '#services',
		'enable_infinite_sliding'                     => true,
		'slider_speed'                                => 800,
		'number_of_slider'                            => 3,
		
		// Service
		'service_title'                               => esc_html__( 'Our services', 'business-center-pro' ),
		'service_sub_title'                           => esc_html__( 'Detailed Analytics', 'business-center-pro' ),
		'enable_service'                              => true,
		'service_content_type'                        => 'demo',
		'number_of_services'                          => 3,
		
		// Features
		'enable_feature'                              => true,
		'feature_content_type'                        => 'demo',
		'number_of_features'                          => 5,
		'custom_feature_view_more_text'               => esc_html__( 'View More', 'business-center-pro' ),
		'custom_feature_view_more_link'               => '#',
		'feature_icon_type'                           => 'img-icon',
		
		// Testimonial
		'enable_testimonial'                          => true,
		'testimonial_title'                           => esc_html__( 'TESTIMONIALS', 'business-center-pro' ),
		'testimonial_sub_title'                       => esc_html__( 'What our clients say?', 'business-center-pro' ),
		'testimonial_content_type'                    => 'demo',
		'number_of_testimonials'                      => 5,	
		
		// Portfolio
		'enable_portfolio'                            => true,
		'portfolio_title'                             => esc_html__( 'Portfolio', 'business-center-pro' ),
		'portfolio_sub_title'                         => esc_html__( 'Our work looks like?', 'business-center-pro' ),
		'portfolio_content_type'                      => 'demo',
		'number_of_portfolios'                        => 6,
		
		// Call To Action
		'enable_call_to_action'                       => true,
		'call_to_action_content_type'                 => 'demo',
		'call_to_action_title'                        => esc_html__( 'Better together', 'business-center-pro' ),
		'call_to_action_sub_title'                    => esc_html__( 'Would like to join us?', 'business-center-pro' ),		
		'call_to_action_content'                      => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi et elit ac justo auctor sodales at eu nunc. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod.', 'business-center-pro' ),		
		'call_to_action_btn_txt'                      => esc_html__( 'JOIN US TODAY', 'business-center-pro' ),		
		'call_to_action_btn_url'                      => '#',		
			
		// Pricing
		'enable_pricing'                              => true,
		'pricing_content_type'                        => 'demo',
		'pricing_title'                               => esc_html__( 'Pricing table', 'business-center-pro' ),
		'pricing_sub_title'                           => esc_html__( "Choose Something That's Suits You", 'business-center-pro' ),		
		'number_of_pricing'                           => 4,
		
		// Front Page Blog
		'enable_front_page_blog'                      => true,
		'front_page_blog_title'                       => esc_html__( 'News', 'business-center-pro' ),
		'front_page_blog_sub_title'                   => esc_html__( 'Always Upto Date', 'business-center-pro' ),		
		'front_page_blog_posts_read_more_btn_txt'     => esc_html__( 'Read More News', 'business-center-pro' ),		
		'front_page_blog_posts_read_more_btn_txt_url' => '#',		
		'front_page_blog_posts_number'                => 3,
		'front_page_blog_content_type'                => 'demo',
		
		// Team
		'enable_team'                                 => true,
		'team_title'                                  => esc_html__( 'Our team', 'business-center-pro' ),
		'team_sub_title'                              => esc_html__( 'Amazing Pupils Working Together', 'business-center-pro' ),		
		'number_of_team'                              => 4,
		'team_content_type'                           => 'demo',
		'team_read_more_btn_txt'                      => esc_html__( 'View More', 'business-center-pro' ),
		'team_read_more_btn_txt_url'                  => '#',
		
		// Skill
		'enable_skill'                                => true,
		'skill_title'                                 => esc_html__( 'Our skills', 'business-center-pro' ),
		'skill_sub_title'                             => esc_html__( 'We are proud of', 'business-center-pro' ),		
		'skill_content_type'                          => 'demo',
		'number_of_skill'                             => 4,
		
		// Client
		'enable_client'                               => true,
		'client_title'                                => esc_html__( 'Featured clients', 'business-center-pro' ),
		'client_sub_title'                            => esc_html__( 'Proud to work with', 'business-center-pro' ),		
		'client_content_type'                         => 'demo',
		'number_of_client'                            => 6,
		
		// Contact
		'enable_contact'                              => true,
		'custom_contact_image'						  => get_template_directory_uri() . '/assets/uploads/contact-us-bg.jpg',
		'contact_title'                               => esc_html__( 'Contact', 'business-center-pro' ),
		'contact_sub_title'                           => esc_html__( 'Keep in touch', 'business-center-pro' ),		
		'contact_content_type'                        => 'demo',
	);

	$output = apply_filters( 'business_center_pro_default_theme_options', $business_center_pro_default_options );
	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}