<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Business Center Pro 2.0.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function business_center_pro_body_classes( $classes ) {
	$options = business_center_pro_get_theme_options();

	// Add class only when laoder is disabled
	if ( ! $options['loader_enable'] ) {
		$classes[] = 'display-none';
	}

	if ( $options['make_menu_sticky'] ) {
		$classes[] = 'nav-shrink';
	}
	// Add a class for typography
   	$typography = (  $options['theme_typography'] == 'default' ) ? '' :  $options['theme_typography'];
   	$classes[] = esc_attr( $typography );

	// Add class on the basis of overlay type choosen
	if ( 'white' == $options['slider_overlay'] ) {
		$classes[] = 'white-overlay';
	} elseif( 'gray' == $options['slider_overlay'] ) {
		$classes[] = 'gray-overlay';
	}
	//Adds extra menu position
	if ( $options['menu_position'] == 'simple-header' ) {
		$classes[] = 'header-one';
	}

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Add a class for layout
	$classes[] = esc_attr( $options['site_layout'] );

	$sidebar_position = business_center_pro_layout();

	if ( class_exists( 'WooCommerce' ) && is_woocommerce() ) {
		$classes[] = 'no-sidebar';
	} elseif ( is_search() || is_404() ) {
		$classes[] = 'right-sidebar';
	} else {
		if ( is_active_sidebar( 'sidebar-1' ) || is_active_sidebar( 'sidebar-2' ) ) {
			$classes[] = esc_attr( $sidebar_position );
		} else {
			$classes[] = 'no-sidebar';
		}
	}
	if ( 'only-caption' == $options['slider_overlay'] ) {
		$classes[] = 'main-slider-style';
	}
	return $classes;
}
add_filter( 'body_class', 'business_center_pro_body_classes' );


/**
 * Adds custom classes to the array of post classes.
 *
 * @param array $classes Classes for the post element.
 * @return array
 */
function business_center_pro_post_classes( $classes ) {
	$classes[] = 'column-wrapper';

	return $classes;
}
add_filter( 'post_class', 'business_center_pro_post_classes' );


/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function business_center_pro_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', bloginfo( 'pingback_url' ), '">';
	}
}
add_action( 'wp_head', 'business_center_pro_pingback_header' );
