<?php
/**
 * Business Center Pro pro custom helper funtions
 *
 * This is the template that includes all the other files for core featured of Business Center Pro
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */

if( ! function_exists( 'business_center_pro_check_enable_status' ) ):
	/**
	 * Check status of content.
	 *
	 * @since Business Center Pro 2.0.0
	 */
  	function business_center_pro_check_enable_status( $input, $content_enable ){
		$options = business_center_pro_get_theme_options();

		// Content status.
		$content_status = $options[ $content_enable ];

		// Get Page ID outside Loop.
		$query_obj = get_queried_object();
		$page_id   = null;
	    if ( is_object( $query_obj ) && 'WP_Post' == get_class( $query_obj ) ) {
	    	$page_id = get_queried_object_id();
	    }

		// Front page displays in Reading Settings.
		$page_on_front  = get_option( 'page_on_front' );

		if ( ( ( ! is_home() && is_front_page() ) && $content_status ) ) {
			$input = true;
		}
		else {
			$input = false;
		}
		return ( $input );

  	}
endif;
add_filter( 'business_center_pro_section_status', 'business_center_pro_check_enable_status', 10, 2 );


if ( ! function_exists( 'business_center_pro_is_sidebar_enable' ) ) :
	/**
	 * Check if sidebar is enabled in meta box first then in customizer
	 *
	 * @since Business Center Pro 2.0.0
	 */
	function business_center_pro_is_sidebar_enable( $sidebar_position_para = '' ) {
		$options               = business_center_pro_get_theme_options();
		$sidebar_position      = $options['sidebar_position'];

		if ( is_home() ) {
			$post_id = get_option( 'page_for_posts' );
			if( ! empty( $post_id ) )
				$post_sidebar_position = get_post_meta( $post_id, 'business-center-pro-sidebar-position', true );
			else
				$post_sidebar_position = '';
		} elseif( is_archive() || is_search() ) {
			$post_sidebar_position = '';
		} else {
			$post_sidebar_position = get_post_meta( get_the_id(), 'business-center-pro-sidebar-position', true );
		}

		if ( ( $sidebar_position == 'no-sidebar' && $post_sidebar_position == "" ) || $post_sidebar_position == 'no-sidebar' ) {
			return false;
		} elseif( 'right' == $sidebar_position_para && ( ( 'right-sidebar' == $post_sidebar_position || 'both-sidebar' == $post_sidebar_position ) || ( ( 'right-sidebar' == $sidebar_position || 'both-sidebar' == $sidebar_position || 'both-sidebar' == $post_sidebar_position ) && "" == $post_sidebar_position ) ) ) {
			return true;
		} elseif( 'left' == $sidebar_position_para && ( ( 'left-sidebar' == $post_sidebar_position || 'both-sidebar' == $post_sidebar_position ) || ( ( 'left-sidebar' == $sidebar_position || 'both-sidebar' == $sidebar_position || 'both-sidebar' == $post_sidebar_position ) && "" == $post_sidebar_position ) ) ) {
			return true;
		} else {
			return false;
		}

	}
endif;


if ( ! function_exists( 'business_center_pro_is_frontpage_content_enable' ) ) :
	/**
	 * Check home page ( static ) content status.
	 *
	 *.0
	 *
	 * @param bool $status Home page content status.
	 * @return bool Modified home page content status.
	 */
	function business_center_pro_is_frontpage_content_enable( $status ) {
		if ( is_front_page() ) {
			$options = business_center_pro_get_theme_options();
			$front_page_content_status = $options['enable_frontpage_content'];
			if ( false === $front_page_content_status ) {
				$status = false;
			}
		}
		return $status;
	}

endif;
add_filter( 'business_center_pro_filter_frontpage_content_enable', 'business_center_pro_is_frontpage_content_enable' );


if ( ! function_exists( 'business_center_pro_pagination' ) ) :

	/**
	 * Pagination.
	 *
	 * @since Business Center Pro 2.0.0
	 */
	function business_center_pro_pagination() {
		$options = business_center_pro_get_theme_options();

		// Bail if pagination is disabled
		if ( false == $options['pagination_enable'] )
			return;

		$pagination_type = $options['pagination_type'];

		switch ( $pagination_type ) {

			case 'default':
				the_posts_navigation();
			break;

			case 'numeric':
				the_posts_pagination( array( 'mid_size' => 5 ) );
			break;

			default:
			break;
		}
	}
endif;
add_action( 'business_center_pro_pagination', 'business_center_pro_pagination', 10 );


if ( ! function_exists( 'business_center_pro_post_pagination' ) ) :

	/**
	 * post pagination.
	 *
	 * @since Business Center Pro 2.0.0
	 */
	function business_center_pro_post_pagination() {
		the_post_navigation();
	}
endif;
add_action( 'business_center_pro_action_post_pagination', 'business_center_pro_post_pagination', 10 );


/**
 * long excerpt
 *
 * @since Business Center Pro 2.0.0
 * @return  long excerpt value
 */
function business_center_pro_excerpt_length( $length ){
	if( is_admin() ) {
		return $length;
	}

	$options = business_center_pro_get_theme_options();
	$length = $options['excerpt_length'];
	return (int)$length;
}
add_filter( 'excerpt_length', 'business_center_pro_excerpt_length', 999 );

/**
 * Excerpt read more text
 *
 * @since Business Center Pro 2.0.0
 * @return  string Excerpt read more string
 */
function business_center_pro_excerpt_more( $more ){
	$options = business_center_pro_get_theme_options();
	$more =  $options['read_more_text'];

	return '... <a class="btn btn-yellow" href="'.esc_url( get_the_permalink() ).'">' . esc_html( $more ) . '</a>';
}
add_filter( 'excerpt_more', 'business_center_pro_excerpt_more' );

/**
 * custom excerpt function
 *
 * @since Business Center Pro 2.0.0
 * @return  no of words to display
 */
function business_center_pro_trim_content( $length = 40, $post_obj = null ) {
	global $post;
	if ( is_null( $post_obj ) ) {
		$post_obj = $post;
	}

	$length = absint( $length );
	if ( $length < 1 ) {
		$length = 40;
	}

	$source_content = $post_obj->post_content;
	if ( ! empty( $post_obj->post_excerpt ) ) {
		$source_content = $post_obj->post_excerpt;
	}

	$source_content = preg_replace( '`\[[^\]]*\]`', '', $source_content );
	$trimmed_content = wp_trim_words( $source_content, $length, '...' );

   return apply_filters( 'business_center_pro_trim_content', $trimmed_content );
}

if ( ! function_exists( 'business_center_pro_is_jetpack_cpt_module_enable' ) ) :
    /**
     * Check if JetPack module is enabled
     *
     * @since Business Center Pro 2.0.0
     *
     * @param string $jetpack_cpt_option 		Jetpack enable checkbox value
     */
    function business_center_pro_is_jetpack_cpt_module_enable( $jetpack_cpt_option ) {
		if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'custom-content-types' ) &&  get_option( $jetpack_cpt_option ) ) :
			return true;
		endif;

		return false;
    }
endif;
add_action( 'plugins_loaded', 'business_center_pro_is_jetpack_cpt_module_enable' );
add_filter( 'business_center_pro_filter_is_jetpack_cpt_module_enable', 'business_center_pro_is_jetpack_cpt_module_enable' );


if ( ! function_exists( 'business_center_pro_footer_sidebar_class' ) ) :
	/**
	 * Count the number of footer sidebars to enable dynamic classes for the footer
	 *
	 * @since Business Center Pro 2.0.0
	 */
	function business_center_pro_footer_sidebar_class() {
		$data = array();
		$active_id = array();
	   	$count = 0;

	   	if ( is_active_sidebar( 'footer-1' ) ) {
	   		$active_id[] = '1';
	      	$count++;
	   	}

	   	if ( is_active_sidebar( 'footer-2' ) ){
	   		$active_id[] = '2';
	      	$count++;
		}

	   	if ( is_active_sidebar( 'footer-3' ) ){
	   		$active_id[] = '3';
	      	$count++;
	   	}

	   	$class = '';

	   	switch ( $count ) {
        	case '1':
            	$class = 'one';
            break;

        	case '2':
            	$class = 'two';
            break;

        	case '3':
            	$class = 'three';
            break;

            default:
            	$class = 'one';
            break;
	   	}

		$data['active_id'] = $active_id;
		$data['class']     = $class;

	   	return $data;
	}
endif;


if ( ! function_exists( 'business_center_pro_custom_content_width' ) ) :

	/**
	 * Custom content width.
	 *
	 * @since 1.0
	 */
	function business_center_pro_custom_content_width() {

		global $content_width;
		$sidebar_position = business_center_pro_layout();
		switch ( $sidebar_position ) {

		  case 'no-sidebar':
		    $content_width = 1170;
		    break;

		  case 'right-sidebar':
		    $content_width = 819;
		    break;

		  default:
		    break;
		}
		if ( ! is_active_sidebar( 'sidebar-1' ) ) {
			$content_width = 1170;
		}

	}
endif;
add_action( 'template_redirect', 'business_center_pro_custom_content_width' );


if ( ! function_exists( 'business_center_pro_layout' ) ) :
	/**
	 * Check home page layout option
	 *
	 * @since Business Center Pro 2.0.0
	 *
	 * @return string Layout value
	 */
	function business_center_pro_layout() {
		$options = business_center_pro_get_theme_options();

		$sidebar_position = $options['sidebar_position'];
		$sidebar_position = apply_filters( 'business_center_pro_sidebar_position', $sidebar_position );
		// Check if single and static blog page
		if ( is_singular() || is_home() ) {
			if ( is_home() ) {
				$post_sidebar_position = get_post_meta( get_option( 'page_for_posts' ), 'business-center-pro-sidebar-position', true );
			} else {
				$post_sidebar_position = get_post_meta( get_the_ID(), 'business-center-pro-sidebar-position', true );
			}
			if ( isset( $post_sidebar_position ) && ! empty( $post_sidebar_position ) ) {
				$sidebar_position = $post_sidebar_position;
			}
		}
		return $sidebar_position;
	}
endif;


if ( ! function_exists( 'business_center_pro_title_as_per_template' ) ) :
	/**
	 * Return title as per template rendered
	 *
	 * @since Business Center Pro 1.0.0
	 *
	 * @return string Template title
	 */
	function business_center_pro_title_as_per_template() {
        if ( is_single() ) {
            $categories_list = get_the_category_list( esc_html__( ', ', 'business-center-pro' ) );
			if ( $categories_list && business_center_pro_categorized_blog() ) {
				printf( '<h2 class="entry-title">%s</h2>', $categories_list ); // WPCS: XSS OK.
			}
        } elseif ( is_archive() ) {
        	echo '<h2 class="entry-title">'.esc_html__( 'Archive', 'business-center-pro' ).'</h2>';
        }

      	if ( is_singular() ) {
      		the_title( '<h1>', '</h1>' );
      	} elseif ( is_archive() ) {
      		the_archive_title( '<h1>', '</h1>' );
      	} elseif( is_404() ) {
			echo '<h1>' . esc_html__( '404 Page', 'business-center-pro' ) . '</h1>';
		} elseif( is_search() ){
			echo '<h1>' . esc_html__( 'Search Page', 'business-center-pro' ) . '</h1>';
		} elseif ( is_home() ) {
			echo '<h1>' . esc_html__( 'Blog Page', 'business-center-pro' ) . '</h1>';
		}
	}
endif;


if ( ! function_exists( 'business_center_pro_column_number' ) ) :
	/**
	 * Return column string number as per the column number
	 *
	 * @since Business Center Pro 1.0.0
	 *
	 * @return string Column number
	 */
	function business_center_pro_column_number( $column_number = 4 ) {
      	if ( $column_number == 1 ) {
      		return 'one';
      	} elseif ( $column_number == 2 ) {
      		return 'two';
      	} elseif( $column_number == 3 ) {
      		return 'three';
		} elseif($column_number == 4 ){
      		return 'four';
		}
	}
endif;

if ( ! function_exists( 'business_center_pro_blog_layout' ) ) :
	/**
	 * Return column number on the basis of value from customizer
	 *
	 * @since Business Center Pro 1.0.0
	 *
	 * @return string Column number
	 */
	function business_center_pro_blog_layout() {

		$options = business_center_pro_get_theme_options();

      	if ( isset( $options['blog_layout'] ) ) {
      		return $options['blog_layout'];
      	} else {
      		return "three";
      	}
	}
endif;


if ( ! function_exists( 'business_center_pro_portfolio_ajax_handler' ) ) :
	/**
	 * ajax handler
	 *
	 * @since Business Center Pro 1.0
	 */
	function business_center_pro_portfolio_ajax_handler(){

		$portfolio_ids = ( isset( $_POST['category'] ) ) ? $_POST['category'] : array();

	    $page = ( isset( $_POST['pageNumber'] ) ) ? $_POST['pageNumber'] : 1;

	    header("Content-Type: text/html");

	    $portfolio_args = array(
	        'post_type' 		=> 'post',
	        'posts_per_page' 	=> absint( get_option( 'posts_per_page', 7 ) ),
	        'category__in'      => $portfolio_ids,
	        'paged'    			=> $page,
	    );

        $portfolio_posts = get_posts( $portfolio_args );
        if( !empty( $portfolio_posts ) ) :

            $index = 1;

            foreach ( $portfolio_posts as $key => $portfolio_post ) {
                if( ( $index % 7  == 3 ) || ( $index % 7  == 0 ) ) {
                    $item = 2;
                }
                else{
                    $item = 1;
                }

                $portfolio_post_id = $portfolio_post->ID;

                if ( has_post_thumbnail( $portfolio_post_id ) ) {
                    $featured_img = wp_get_attachment_image_src( get_post_thumbnail_id( $portfolio_post->ID ), 'large' );
                    $img_array = $featured_img[0];
                } else {
                    $img_array =  get_template_directory_uri() . '/assets/uploads/no-featured-image-1300x600.jpg';
                }
                if ( isset( $img_array ) ) {
                  $post_image['img_array'][0] = $img_array;
                }
                $post_title        = get_the_title( $portfolio_post_id );
                $post_url          = get_the_permalink( $portfolio_post_id );
                $post_categories   = get_the_category( $portfolio_post_id );

                $post_category_list = '';
                $post_category_name = '';
                foreach ( $post_categories as $key => $post_category ) {
                    $post_category_name .= $post_category->name . ' ';
                    $post_category_list .= $post_category->slug . ' ';
                } ?>

                <div class="portfolio-item item-w<?php echo esc_attr( $item ); ?> <?php echo esc_attr( $post_category_list ); ?> ">
                    <div class="portfolio-featured-image" style="background-image:url(<?php echo esc_url( $post_image['img_array'][0] ); ?>);">
                        <div class="portfolio-hover">
                            <span class="item-category"></span><?php echo esc_html( $post_category_name ); ?></span>
                            <span class="item-title"><a href="<?php echo esc_url( $post_url ); ?>"><?php echo esc_html( $post_title ); ?></a></span>
                        </div><!-- .portfolio-hover -->
                    </div><!-- .portfolio-featured-image -->
                </div><!-- .portfolio-item -->
            <?php $index++ ;}
        endif;
	    die();
	}
endif;
add_action("wp_ajax_business_center_pro_portfolio_ajax_handler", "business_center_pro_portfolio_ajax_handler");
add_action("wp_ajax_nopriv_business_center_pro_portfolio_ajax_handler", "business_center_pro_portfolio_ajax_handler");


if ( ! function_exists( 'business_center_pro_trim_content' ) ) :
	/**
	 * custom excerpt function
	 *
	 * @since Business Center Pro 2.0.1
	 * @return  no of words to display
	 */
	function business_center_pro_trim_content( $length = 40, $post_obj = null ) {
		global $post;
		if ( is_null( $post_obj ) ) {
			$post_obj = $post;
		}

		$length = absint( $length );
		if ( $length < 1 ) {
			$length = 40;
		}

		$source_content = $post_obj->post_content;
		if ( ! empty( $post_obj->post_excerpt ) ) {
			$source_content = $post_obj->post_excerpt;
		}

		$source_content = preg_replace( '`\[[^\]]*\]`', '', $source_content );
		$trimmed_content = wp_trim_words( $source_content, $length, '...' );

	   return apply_filters( 'business_center_pro_trim_content', $trimmed_content );
	}
endif;