<?php
/**
 * Business Center Pro metabox for sidebar positions.
 *
 * This is the template that includes all the codes for the metabox of slider layout
 *
 * @package Theme Palace
 * @since Business Center Pro 2.0.0
 */

/**
 * Outputs the content of the sidebar position
 */
function business_center_pro_sidebar_position_callback( $post ) {
    wp_nonce_field( basename( __FILE__ ), 'business_center_pro_nonce' );
    $stored_sidebar_position = get_post_meta( $post->ID, 'business-center-pro-sidebar-position', true );

    $sidebar_positions       = business_center_pro_sidebar_position();
    ?>

    <p>
     <label for="business-center-pro-sidebar-position" class="business-center-pro-row-title"><?php esc_html_e( 'Sidebar Position', 'business-center-pro' )?></label>
     <select name="business-center-pro-sidebar-position" id="business-center-pro-sidebar-position">
      <option value=""><?php esc_html_e( 'Default ( to customizer option )', 'business-center-pro' ); ?></option>

        <?php foreach ( $sidebar_positions as $sidebar_position => $value ) { ?>
         <option value="<?php echo esc_attr( $sidebar_position );?>" <?php if ( isset ( $stored_sidebar_position ) ) selected( $stored_sidebar_position, $sidebar_position ); ?>><?php echo esc_html( $value ); ?></option>
        <?php } ?>
     </select>
    </p>
    <?php
}


/**
 * Saves the sidebar position input
 */
function business_center_pro_sidebar_layout_save( $post_id ) {

    // Checks save status
    $is_autosave = wp_is_post_autosave( $post_id );
    $is_revision = wp_is_post_revision( $post_id );
    $is_valid_nonce = ( isset( $_POST[ 'business_center_pro_nonce' ] ) && wp_verify_nonce( sanitize_key( $_POST[ 'business_center_pro_nonce' ] ), basename( __FILE__ ) ) ) ? 'true' : 'false';

    // Exits script depending on save status
    if ( $is_autosave || $is_revision || ! $is_valid_nonce ) {
        return;
    }

    // Checks for input and sanitizes/saves if needed
    if( isset( $_POST[ 'business-center-pro-sidebar-position' ] ) ) {
        update_post_meta( $post_id, 'business-center-pro-sidebar-position', sanitize_text_field( $_POST[ 'business-center-pro-sidebar-position' ] ) );
    }

}
add_action( 'save_post', 'business_center_pro_sidebar_layout_save' );