<?php
/**
 * Menu
 *
 * This is the template for all registered menus
 *
 * @package Theme Palace
 * @subpackage Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */

if ( ! function_exists( 'business_center_pro_navigation' ) ) :
	/**
	 * Add primary menu
	 *
	 * @since Business Center Pro 2.0.0
	 *
	 */
	function business_center_pro_navigation() {
		?>
        <?php if ( has_nav_menu( 'primary' ) ) : ?>
			<nav id="site-navigation" class="main-navigation" role="navigation">
	        	<button class="menu-toggle">
	            <span class="menu-icon">
	              <span class="icon-bar"></span>
	              <span class="icon-bar"></span>
	              <span class="icon-bar"></span>
		          </span><!-- .menu-icon -->
		        </button><!-- .menu-toggle -->
		        <div class="menu-close"><i class="fa fa-close"></i></div>
				<?php wp_nav_menu( array( 'theme_location' => 'primary', 'container' => 'ul', 'menu_id' => 'primary-menu' ) ); ?>
			</nav><!-- #site-navigation -->
        <?php
        endif;
	}
endif;
add_action( 'business_center_pro_header', 'business_center_pro_navigation', 20 );


if ( ! function_exists( 'business_center_pro_append_search' ) ) :
	/**
	 * Add search bar to menu
	 */

	function business_center_pro_append_search() {
			$options        = business_center_pro_get_theme_options();

			$append_search = $options['append_search'];

		   // Search Box
		   if ( $append_search ) { ?>
		   		<div id="search">
		   		  <i class="fa fa-search"></i>
		   		  <form action="<?php echo esc_url( home_url( '/' ) ); ?>" method="get">
		   		    <input name="s" type="search" id="search" class="search-field" placeholder="<?php echo esc_attr__( 'search', 'business-center-pro' ); ?>">
		   		    <i class="fa fa-close"></i>
		   		  </form>
		   		</div><!-- #search -->
		   <?php
			}
	}
endif;

add_action('business_center_pro_header','business_center_pro_append_search', 30 );


function business_center_pro_search_ajax_enqueuer() {

	$categories_id = get_post_meta( get_the_id(), 'business-center-pro-portfolio-template', true );
   wp_register_script( "business-center-pro-ajax", get_template_directory_uri() . '/assets/js/ajax.min.js', array('jquery') );
   wp_localize_script( 'business-center-pro-ajax', 'myAjax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ),'category' => $categories_id ) );
   wp_enqueue_script( 'business-center-pro-ajax' );
}
add_action( 'wp_enqueue_scripts', 'business_center_pro_search_ajax_enqueuer' );


function business_center_pro_ajax_search_result(){
	$search_txt = esc_attr( $_POST['search_txt'] );
	$args = array(
	    's' => $search_txt,
  	);
  	$search_query = new WP_Query( $args );
  	?>

  	<div class="found-results">
        <div class="search-title">
          <h3><?php echo esc_html( $search_txt );?></h3>
        </div><!-- .search-title -->
        <div class="container three-columns">
        <?php
        if ( $search_query->have_posts() ) {
        	while ( $search_query->have_posts() ) {
        		$search_query->the_post();?>
	          	<article id="post-1" class="column-wrapper has-post-thumbnail hentry">
		            <div class="image-wrapper">
		              <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
		              <?php the_post_thumbnail(); ?>
		              </a><!-- .post-thumbnail -->
		            </div><!-- .image-wrapper -->

		            <header class="entry-header">
		              <p class="entry-meta">
		                <span class="posted-on"><span class="screen-reader-text"><?php esc_html__( 'Posted on', 'business-center-pro' ); ?></span>
		                    <time class="entry-date published"><?php the_date();?></time>
		                </span><!-- end .posted-on -->
		              </p><!-- .entry-meta -->
		              <h2 class="entry-title"><a href="<?php the_permalink();?>" rel="bookmark"><?php the_title(); ?></a></h2>
		            </header><!-- .entry-header -->
		            <div class="entry-content">
		              <?php the_excerpt();?>
		            </div><!-- .entry-content -->
	          	</article><!-- end #post-1 -->
          	<?php
        	}
	  		wp_reset_postdata();
        } else {
        	echo esc_html__( 'No Results Found', 'business-center-pro' );
        }
        ?>
        </div><!-- .three-columns -->
  	</div><!-- .recent-searches -->
	<?php
	die();
}
add_action("wp_ajax_business_center_pro_ajax_search_result", "business_center_pro_ajax_search_result");
add_action("wp_ajax_nopriv_business_center_pro_ajax_search_result", "business_center_pro_ajax_search_result");


if ( ! function_exists( 'business_center_pro_search_result' ) ) :
	/**
	 * Add search bar to menu
	 */

	function business_center_pro_search_result() {
		$options  = business_center_pro_get_theme_options();
		?>
   		<div class="search-contents">
		      	<div class="searching-results">
   		        <div class="loader-search-dots">...</div>
   		        <img src="<?php echo get_template_directory_uri() . '/assets/uploads/search-loading.gif';?>" alt="" class="loading-search-results">
		      	</div><!-- .searching-results -->
		    </div><!-- .search-contents -->
	   <?php
	}
endif;

add_action('business_center_pro_header_end','business_center_pro_search_result', 110 );


if ( ! function_exists( 'business_center_pro_social_menu' ) ) :
	/**
	 * Add social menu
	 *
	 * @since Business Center Pro 2.0.0
	 *
	 */
	function business_center_pro_social_menu() {
		if ( has_nav_menu( 'social-link' ) ) :
			 wp_nav_menu( array(
			                    'theme_location' => 'social-link',
			                    'container_class' => 'social-menu',
			                    'container_id' => 'social-menu-1',
			                    // 'menu_id' => 'primary-menu'
			                   ) );
        endif;
	}
endif;
add_action( 'business_center_pro_footer_start', 'business_center_pro_social_menu', 20 );