<?php
/**
 * Portfolio section
 *
 * This is the template for the content of portfolio section
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */

if ( ! function_exists( 'business_center_pro_add_portfolio_section' ) ) :
  /**
   * Add portfolio section
   *
   *@since Business Center Pro 2.0.0
   */
  function business_center_pro_add_portfolio_section() {
    // Check if portfolio is enabled
    $enable_portfolio = apply_filters( 'business_center_pro_section_status', true, 'enable_portfolio' );

    if ( true !== $enable_portfolio ) {
      return false;
    }

    // Get portfolio section details
    $section_details = array();

    $section_details = apply_filters( 'business_center_pro_filter_portfolio_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render portfolio section now.
    business_center_pro_render_portfolio_section( $section_details );
  }
endif;
add_action( 'business_center_pro_core_modules', 'business_center_pro_add_portfolio_section', 30 );


if ( ! function_exists( 'business_center_pro_get_portfolio_section_details' ) ) :
  /**
   * Portfolio section details.
   *
   * @since Business Center Pro 2.0.0
   * @param array $input Portfolio section details.
   */
  function business_center_pro_get_portfolio_section_details( $input ) {
    $options = business_center_pro_get_theme_options();

    // Portfolio type
    $portfolio_content_type  = $options['portfolio_content_type'];

    $content = array();
    switch ( $portfolio_content_type ) {
      	case 'demo':
	        for ( $i=1; $i<=6; $i++ ) {
            $content[ $i ]['alt']      = esc_html__( 'Demo Testimonial', 'business-center-pro' );
            $content[ $i ]['link']      = '#';
            $content[ $i ]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/portfolio-0'.$i.'.jpg';
	        }
      	break;

        case 'custom':
          for ( $i=1; $i<=$options['number_of_portfolios']; $i++ ) {
            $content[ $i ]['alt'] = '';
            if ( isset( $options['custom_portfolio_alt_text_'.$i] ) ) {
              $content[ $i ]['alt']      = $options['custom_portfolio_alt_text_'.$i];
            }
            $content[ $i ]['link'] = '';
            if ( isset( $options['custom_portfolio_alt_text_'.$i] ) ) {
              $content[ $i ]['link']      = $options['custom_portfolio_url_'.$i];
            }
            if ( ! empty( $options['custom_portfolio_image_'.$i] ) ) {
              $content[ $i ]['img_array'][0] = $options['custom_portfolio_image_'.$i];
            } else {
              $content[ $i ]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/user.png';
            }
          }
        break;

      	case 'category':
	        $cat_id = array();
	        if ( !empty( $options['portfolio_category'] ) ) {
	            $cat_id = $options['portfolio_category'];
	        }

	        // Bail if no valid pages are selected.
	        if ( empty( $cat_id ) ) {
	            return $input;
	        }else{
	            $cat_id =  (array)$cat_id;
	        }
	        $args = array(
              'no_found_rows'  => true,
              'category__in'   => $cat_id,
              'post_type'      => 'post',
              'posts_per_page' => absint( $options['number_of_portfolios'] ),
              'orderby'        => 'ASC',
	        );
      	break;

      	default:
      	break;
    }

    if ( 'demo' != $portfolio_content_type && 'custom' != $portfolio_content_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {
            $post_id = $post->ID;

            $content[ $i ]['title']       = get_the_title( $post_id );
            $content[ $i ]['sub_title']   = get_post_field('post_content', $post_id);

            $content[ $i ]['link']      = get_permalink( $post_id );
            $content[ $i ]['name_company']     = get_the_title( $post_id );
            if ( has_post_thumbnail( $post_id ) ) {
                $featured_img = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'large' );
                $img_array = $featured_img[0];
            } else {
                $img_array =  get_template_directory_uri() . '/assets/uploads/no-featured-image-1300x600.jpg';
            }

            if ( isset( $img_array ) ) {
              $content[$i]['img_array'][0] = $img_array;
            }

            $content[ $i ]['content'] = get_post_field( 'post_content', $post_id );

            $i++;
          }
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Portfolio section content details.
add_filter( 'business_center_pro_filter_portfolio_section_details', 'business_center_pro_get_portfolio_section_details' );


if ( ! function_exists( 'business_center_pro_render_portfolio_section' ) ) :
  /**
   * Start portfolio section
   *
   * @return string Portfolio content
   * @since Business Center Pro 2.0.0
   *
   */
   function business_center_pro_render_portfolio_section( $content_details = array() ) {
        $options = business_center_pro_get_theme_options();

        if ( empty( $content_details ) ) {
          return;
        }
        ?>
        <section id="portfolio-slider" class="page-section no-padding-top">
          <div class="container">
            <header class="entry-header">
              <div class="separate"></div>
              <?php if ( !empty( $options['portfolio_title'] ) ) { ?>
                <h2 class="entry-title category-title"><?php echo esc_html( $options['portfolio_title'] );?></h2>
              <?php } ?>
              <?php if ( !empty( $options['portfolio_sub_title'] ) ) { ?>
                <p class="subtitle"><?php echo esc_html( $options['portfolio_sub_title'] );?></p>
              <?php } ?>
            </header><!-- .entry-header -->

            <div class="entry-content center row" data-slick='{"slidesToShow": <?php echo esc_attr( absint( $options['number_of_portfolios'] ) - 1 );?>, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": false, "arrows": false, "autoplay": true, "fade": false, "draggable": false, "focusOnSelect": true, "centerMode":true }'>
            <?php foreach ( $content_details as $content ) { ?>
              <div class="slider-item">
                <a href="<?php echo ( ! empty( $content['link'] ) ) ? esc_url( $content['link'] ) : '';?>">
                  <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['img_array'][0] );?>');"></div><!-- .featured-image -->
                </a>
              </div><!-- .slider-item -->
            <?php } ?>
            </div><!--.entry-content-->
          </div><!-- .container -->
        </section><!-- #portfolio -->
<?php
    }
endif;