<?php 
/**
 * Pricing section
 *
 * This is the template for the content of pricing section
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */

if ( ! function_exists( 'business_center_pro_add_pricing_section' ) ) :
  /**
   * Add pricing section
   *
   *@since Business Center Pro 2.0.0
   */
  function business_center_pro_add_pricing_section() {
    // Check if pricing is enabled
    $enable_pricing = apply_filters( 'business_center_pro_section_status', true, 'enable_pricing' );

    if ( true !== $enable_pricing ) {
      return false;
    }

    // Get pricing section details
    $section_details = array();

    $section_details = apply_filters( 'business_center_pro_filter_pricing_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render pricing section now.
    business_center_pro_render_pricing_section( $section_details );
  }
endif;
add_action( 'business_center_pro_core_modules', 'business_center_pro_add_pricing_section', 30 );


if ( ! function_exists( 'business_center_pro_get_pricing_section_details' ) ) :
  /**
   * Pricings section details.
   *
   * @since Business Center Pro 2.0.0
   * @param array $input Pricings section details.
   */
  function business_center_pro_get_pricing_section_details( $input ) {
    $options = business_center_pro_get_theme_options();

    // Pricings type
    $pricing_content_type  = $options['pricing_content_type'];

    $content = array();
    switch ( $pricing_content_type ) {
      	case 'demo':
          $title_arr = array( 
                             esc_html__( 'Starter', 'business-center-pro' ), 
                             esc_html__( 'Professional', 'business-center-pro' ), 
                             esc_html__( 'Business', 'business-center-pro' ), 
                             esc_html__( 'Enterprise', 'business-center-pro' ), 
                            );
	        for ( $i=0; $i<=3; $i++ ) {
            $content[ $i ]['title'] = $title_arr[ $i ];
            $content[ $i ]['content'] = '<p><sup>$</sup>12<sub>/MO</sub></p>
                       <ul>
                         <li><strong>'.esc_html__( 'Full', 'business-center-pro' ) . '</strong> '.esc_html__( 'Access', 'business-center-pro' ) . '</li>
                         <li>'.esc_html__( 'Source Files', 'business-center-pro' ) . '</li>
                         <li><strong>100</strong> '.esc_html__( 'user accounts', 'business-center-pro' ) . '</li>
                         <li><strong>1</strong> '.esc_html__( 'Year License', 'business-center-pro' ) . '</li>
                         <li>'.esc_html__( 'Phone &amp; email support', 'business-center-pro' ) . '</li>
                       </ul>';
            $content[ $i ]['btn_txt']   = esc_html__( 'SIGN UP NOW', 'business-center-pro' );
            $content[ $i ]['btn_txt_url']   = '#';
	        }
      	break;

        case 'custom':
          for ( $i=1; $i<=$options['number_of_pricing']; $i++ ) {
            if ( isset( $options['custom_pricing_title_'.$i] ) ) {
              $content[ $i ]['title']       = $options['custom_pricing_title_'. $i ];
            }
            if ( isset( $options['custom_pricing_content_'.$i] ) ) {
              $content[ $i ]['content']     = $options['custom_pricing_content_'. $i ];
            }
            if ( isset( $options['custom_pricing_button_text_'.$i] ) ) {
              $content[ $i ]['btn_txt']     = $options['custom_pricing_button_text_'. $i ];
            }
            if ( isset( $options['custom_pricing_btn_url_'.$i] ) ) {
              $content[ $i ]['btn_txt_url'] = $options['custom_pricing_btn_url_'. $i ];
            }
          }
        break;

      	case 'category':
	        $cat_id = array();
	        if ( !empty( $options['pricing_category'] ) ) {
	            $cat_id = $options['pricing_category'];
	        }

	        // Bail if no valid pages are selected.
	        if ( empty( $cat_id ) ) {
	            return $input;
	        }else{
	            $cat_id =  (array)$cat_id;
	        }
	        $args = array(
              'no_found_rows'  => true,
              'category__in'   => $cat_id,
              'post_type'      => 'post',
              'posts_per_page' => absint( $options['number_of_pricing'] ),
              'orderby'        => 'ASC',
	        );
      	break;

      	default:
      	break;
    }

    if ( 'demo' != $pricing_content_type && 'custom' != $pricing_content_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {
            $post_id = $post->ID;
            $content[ $i ]['title']       = get_the_title( $post_id );;
            $content[ $i ]['content']     = get_the_excerpt( $post_id );
            $content[ $i ]['btn_txt']     = $options['custom_pricing_button_text_'. $i ];
            $content[ $i ]['btn_txt_url'] = get_permalink( $post_id );
            $i++;
          }
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Pricings section content details.
add_filter( 'business_center_pro_filter_pricing_section_details', 'business_center_pro_get_pricing_section_details' );


if ( ! function_exists( 'business_center_pro_render_pricing_section' ) ) :
  /**
   * Start pricing section
   *
   * @return string Pricings content
   * @since Business Center Pro 2.0.0
   *
   */
   function business_center_pro_render_pricing_section( $content_details = array() ) {
        $options = business_center_pro_get_theme_options();

        if ( empty( $content_details ) ) {
          return;
        } 
        ?>
       <section id="pricing-section" class="page-section">
               <div class="container">
                 <header class="entry-header">
                   <div class="separate"></div>
                   <?php if ( ! empty( $options['pricing_title'] ) ) { ?>
                    <h2 class="entry-title"><?php echo esc_html( $options['pricing_title'] ); ?></h2>  
                   <?php } ?>
                   <?php if ( ! empty( $options['pricing_sub_title'] ) ) { ?>
                    <p class="subtitle"><?php echo esc_html( $options['pricing_sub_title'] ); ?></p>
                   <?php } ?>
                 </header><!-- .entry-header -->
                 <div class="pricing row <?php echo esc_attr( business_center_pro_column_number( $options['number_of_pricing'] ) ); ?>-columns">
                  <?php foreach( $content_details as $content ) { ?>
                    <div class="column-wrapper">
                     <div class="pricing-item">
                        <?php if ( ! empty( $content['title'] ) ) { ?>
                           <h4><?php echo esc_html( $content['title'] ); ?></h4>
                        <?php }
                        if ( isset( $content['content'] ) ) {
                          echo wp_kses_post( $content['content'] );
                        } ?>
                        <?php if ( isset( $content['btn_txt'] ) ) { ?>
                         <a href="<?php echo esc_url( $content['btn_txt_url'] );?>" class="btn btn-transparent"><?php echo esc_html( $content['btn_txt'] ); ?></a>
                        <?php } ?>
                     </div><!--.pricing-item-->
                    </div><!--.column-wrapper-->
                  <?php } ?>
                 </div><!-- .pricing-->
               </div><!-- .container-->
             </section><!-- #pricing-section-->
<?php 
    }
endif;