<?php 
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */
if ( ! function_exists( 'business_center_pro_add_slider_section' ) ) :
  /**
   * Add slider section
   *
   *@since Business Center Pro 2.0.0
   */
  function business_center_pro_add_slider_section() {
    // Check if slider is enabled
    $enable_slider = apply_filters( 'business_center_pro_section_status', true, 'enable_slider' );

    if ( true !== $enable_slider ) {
      return false;
    }

    // Get slider section details
    $section_details = array();
    $section_details = apply_filters( 'business_center_pro_filter_slider_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render slider section now.
    business_center_pro_render_slider_section( $section_details );
  }
endif;
add_action( 'business_center_pro_core_modules', 'business_center_pro_add_slider_section', 20 );


if ( ! function_exists( 'business_center_pro_get_slider_section_details' ) ) :
  /**
   * Slider section details.
   *
   * @since Business Center Pro 2.0.0
   * @param array $input Slider section details.
   */
  function business_center_pro_get_slider_section_details( $input ) {
    $options = business_center_pro_get_theme_options();

    // Slider type
    $slider_content_type  = $options['slider_content_type'];

    $content = array();
    switch ( $slider_content_type ) {
      	case 'demo':
	        for ( $i=1; $i<=2; $i++ ) {
	          $content[ $i ]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/slider-0'.$i.'.jpg';
	          $content[ $i ]['url']          = '#';
	          $content[ $i ]['button_text']          = esc_html__( 'START BROWISING', 'business-center-pro' );
	          $content[ $i ]['title']        = esc_html__( 'We Create Awesome Themes', 'business-center-pro' );
            $content[ $i ]['sub_title']   = esc_html__( 'The life of a Designer is a life of fight', 'business-center-pro' );
            $content[ $i ]['alt']          = esc_html__( 'Slider Image', 'business-center-pro' );
	          $content[ $i ]['video_link']          = 'https://www.youtube.com/';
	        }
      	break;

        case 'custom':
          for ( $i=1; $i<=$options['number_of_slider']; $i++ ) {
            if ( isset( $options['custom_slider_image_'.$i] ) ) {
              $content[ $i ]['img_array'][0] = $options['custom_slider_image_'.$i];
            }
            if ( isset( $options['custom_slider_link_'.$i] ) ) {
              $content[ $i ]['url']            = $options['custom_slider_link_'.$i];
            }
            if ( isset( $options['slider_btn_text_'.$i] ) ) {
              $content[ $i ]['button_text']    = $options['slider_btn_text_'.$i];
            }
            if ( isset( $options['custom_slider_title_'.$i] ) ) {
              $content[ $i ]['title']          = $options['custom_slider_title_'.$i];
            }
            if ( isset( $options['slider_sub_title_'.$i] ) ) {
              $content[ $i ]['sub_title']   = $options['slider_sub_title_'.$i];
            }
            if ( isset( $options['custom_slider_title_'.$i] ) ) {
              $content[ $i ]['alt']            = $options['custom_slider_title_'.$i];
            }
            if ( isset( $options['slider_video_link_'.$i] ) ) {
              $content[ $i ]['video_link']          = $options['slider_video_link_'.$i];
            }
          }
        break;

      	case 'page':
          $ids = array();
          for ( $i = 1; $i <= $options['number_of_slider']; $i++ ) {
              $id = null;
              if ( isset( $options[ 'slider_page_'.$i ] ) ) {
                  $id = $options[ 'slider_page_'.$i ];
              }
              if ( ! empty( $id ) ) {
                  $ids[] = absint( $id );
              }
          }
          // Bail if no valid pages are selected.
          if ( empty( $ids ) ) {
              return $input;
          }

	        $args = array(
	            'no_found_rows'  => true,
	            'orderby'        => 'post__in',
	            'post_type'      => 'page',
	            'post__in'       => $ids,
	        );
      	break;

      	case 'category':
	        $cat_id = array();
	        if ( !empty( $options['slider_category'] ) ) {
	            $cat_id = $options['slider_category'];
	        }

	        // Bail if no valid pages are selected.
	        if ( empty( $cat_id ) ) {
	            return $input;
	        }else{
	            $cat_id =  (array)$cat_id;
	        }
	        $args = array(
              'no_found_rows'  => true,
              'category__in'   => $cat_id,
              'post_type'      => 'post',
              'posts_per_page' => absint( $options['number_of_slider'] ),
              'orderby'        => 'ASC',
	        );
      	break;

      	default:
      	break;
    }

    if ( 'demo' != $slider_content_type && 'custom' != $slider_content_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {
              $page_id = $post->ID;
              $img_array = null;
            if ( has_post_thumbnail( $page_id ) ) {
                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'large' );
            } else {
                $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-1300x600.jpg';
            }

            if ( isset( $img_array ) ) {
              $content[$i]['img_array'] = $img_array;
            }

            $content[ $i ]['url']         = get_permalink( $page_id );
            if ( isset( $options['slider_btn_text_'.$i] ) ) {
              $content[ $i ]['button_text'] = $options['slider_btn_text_'. $i];
            }
            $content[ $i ]['title']       = get_the_title( $page_id );
            if ( isset( $options['slider_sub_title_'.$i] ) ) {
              $content[ $i ]['sub_title']   = $options['slider_sub_title_'.$i];
            }
            $content[ $i ]['alt']         = get_the_title( $page_id );
            if ( isset( $options['slider_video_link_'.$i] ) ) {
              $content[ $i ]['video_link']  = $options['slider_video_link_'.$i];
            }

            $i++;
          }
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Slider section content details.
add_filter( 'business_center_pro_filter_slider_section_details', 'business_center_pro_get_slider_section_details' );


if ( ! function_exists( 'business_center_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string Slider content
   * @since Business Center Pro 2.0.0
   *
   */
   function business_center_pro_render_slider_section( $content_details = array() ) {
        $options                 = business_center_pro_get_theme_options();
        $slider_effect           = ( $options['slider_transition'] == 'fade' ) ? 'linear' : $options['slider_transition'];
        $slider_fade             = ( $options['slider_transition'] == 'fade' ) ? 'true' : 'false';
        $enable_slider_pager     = ( $options['enable_slider_pager'] ) ? 'true' : 'false';
        $enable_slider_autoplay  = ( $options['enable_slider_autoplay'] ) ? 'true' : 'false';
        $make_slider_draggable   = ( $options['make_slider_draggable'] ) ? 'true' : 'false';
        $enable_infinite_sliding = ( $options['enable_infinite_sliding'] ) ? 'true' : 'false';
        $slider_speed            = $options['slider_speed'];

        if ( empty( $content_details ) ) {
          return;
        } 
        ?>
        <section id="main-slider" class="featured-slider">
	        <div class="regular" 
	        data-effect="<?php echo esc_attr( $slider_effect ); ?>" 
	        data-slick='{
		        	"slidesToShow": 1, 
		        	"slidesToScroll": 1, 
		        	"infinite": <?php echo esc_attr( $enable_infinite_sliding );?>, 
		        	"speed": <?php echo absint( $slider_speed ); ?>, 
		        	"dots": <?php echo esc_attr( $enable_slider_pager ); ?>, 
		        	"arrows":true, 
		        	"autoplay": <?php echo esc_attr( $enable_slider_autoplay ); ?>, 
		        	"fade": <?php echo esc_attr( $slider_fade ); ?>, 
		        	"draggable": <?php echo esc_attr( $make_slider_draggable ); ?> 
	        	}'>

                <?php foreach ( $content_details as $content ): ?>
		          	<div class="slider-item">
			            <a href="<?php echo ( ! empty( $content['url'] ) ) ? esc_url( $content['url'] ) : '';?>">
                    <img src="<?php echo esc_url( $content['img_array'][0] );?>" alt="">
			              <div class="black-overlay"></div>
                  </a>
                  <?php if( $options['enable_slider_caption'] ) :  ?>
			              <div class="main-slider-contents">
                      <?php if ( ! empty( $content['title'] ) ) { ?>
			                 <h2 class="title"><?php echo esc_html( $content['title'] );?></h2>  
                      <?php } ?>
                      <?php if ( ! empty( $content['sub_title'] ) ) { ?>
			                 <p class="desc"><?php echo esc_html( $content['sub_title'] );?></p>
                      <?php } ?>
			                <a href="<?php echo ( ! empty( $content['url'] ) ) ? esc_url( $content['url'] ) : '';?>" class="btn btn-yellow">
                        <?php echo ( ! empty( $content['button_text'] ) ) ? esc_html( $content['button_text'] ) : ''; ?>
                      </a>
                      <?php if ( ! empty( $content['video_link'] ) ) { ?>
                        <div class="video-link">
                          <a href="<?php echo ( ! empty( $content['video_link'] ) ) ? esc_url( $content['video_link'] ) : ''; ?>" target="_blank">
                            <div class="play-video"><i class="fa fa-play"></i></div>
                          </a>
                        </div><!-- .play-video -->
                      <?php } ?>
			            </div><!-- end .main-slider-contents -->
                <?php endif; ?>
		          	</div><!-- end .slider-item -->
                <?php endforeach; ?>
            </div><!-- end .regular -->
          <?php if ( ! empty( $options['slider_scroll_down_id'] ) ) { ?>
            <div class="scroll-down">
              <a href="<?php echo esc_attr( $options['slider_scroll_down_id'] ); ?>" class="scroll-link"><i class="fa fa-long-arrow-down"></i></a>
            </div>
          <?php }  ?>
	    </section><!-- #main-slider -->          
<?php 
    }
endif;