<?php
/**
 * Theme inline styles and javascripts
 *
 * @package Business Center Pro 2.0.0
 */

if ( ! function_exists( 'business_center_pro_inline_css' ) ) :
	// Add Custom Css
	function business_center_pro_inline_css() {
		$options = business_center_pro_get_theme_options();

		$css = '';

		// Custom header style
		$cusotm_header_style = '';
		$header_text_color = get_header_textcolor();
		if ( get_theme_support( 'custom-header', 'default-text-color' ) != $header_text_color ) {
			if ( ! display_header_text() ) :
				$cusotm_header_style = '
				.site-title,
				.site-description {
					position: absolute;
					clip: rect(1px, 1px, 1px, 1px);
				}';
			else :
				$cusotm_header_style = '
				#site-header .site-title a,
				.site-description {
					color: #' . esc_attr( $header_text_color ). ';
				}';
			endif;
		}

		$slider_opacity_css = '';
		if ( isset( $options['opacity_value'] ) ) {
			$slider_opacity_val = $options['opacity_value'];
			// Slider opacity
			$slider_opacity_css = '
			#main-slider .black-overlay {
			   opacity: '.floatval( $slider_opacity_val ).';
			}';
		}

		// Color layout css
		$color_layout_css = '';
		$color_layout = $options['color_layout'];
		if ( ! empty( $color_layout ) ) {
			$color_layout_css = '
			/*--------------------------------------------------------------
			# TEXT COLORS
			--------------------------------------------------------------*/
			.site-title:hover,
			#site-header .site-title a:hover,
			#search .fa-search:hover,
			#search .fa-close:hover,
			.found-results .fa.fa-close:hover,
			#blog-posts .post-wrapper h5 a:hover,
			article a:hover,
			.btn-yellow:hover,
			#main-slider .slick-dots li:hover button:before,
			.client-name:hover,
			.pricing .column-wrapper:hover .star-rating,
			#team h5 a:hover,
			.call-to-action ul li:hover a,
			.call-to-action ul li:hover .fa,
			.site-footer a:hover,
			.banner-wrapper .byline a:hover,
			.banner-wrapper .posted-on a:hover,
			.scroll-down:hover,
			.site-header .menu-toggle .fa:hover,
			.menu-close .fa:hover,
			body.white-overlay #site-header .site-title a:hover,
			body.white-overlay #search .fa-search:hover,
			body.white-overlay #main-slider .slick-dots li button:hover:before,
			body.white-overlay .scroll-down:hover,
			.loader-container .fa,
			body.white-overlay .site-header.is-sticky #site-header .site-title a:hover,
			body.white-overlay .site-header.is-sticky #search .fa-search:hover,
			.widget ul li a:hover,
			#services .column-wrapper:hover .fa,
			.scroll-down a:hover,
			ul.trail-items li a:hover span,
			ul.trail-items li span,
			footer.entry-footer a:hover,
			span.author.vcard a,
			.woocommerce .star-rating span:before,
			.woocommerce a.button:hover,
			.woocommerce a.added_to_cart:hover,
			label[for="payment_method_paypal"] a:hover,
			p.stars a,
			.woocommerce .star-rating span:before,
			a.woocommerce-review-link {
			    color: '.esc_attr( $color_layout ).';
			}
			/*--------------------------------------------------------------
			# BACKGROUND AND BORDER COLORS
			--------------------------------------------------------------*/
			.btn-yellow,
			.pricing .column-wrapper:hover .btn,
			.woocommerce a.button,
			.woocommerce a.added_to_cart,
			.woocommerce #respond input#submit.alt,
			.woocommerce a.button.alt,
			.woocommerce button.button.alt,
			.woocommerce input.button.alt,
			.woocommerce #review_form #respond .form-submit input,
			.woocommerce button.button.alt.disabled,
			.woocommerce .cart .button,
			.woocommerce .cart input.button,
			.woocommerce input.button:disabled,
			.woocommerce input.button:disabled[disabled] {
			    background-color: '.esc_attr( $color_layout ).';
			    border-color: '.esc_attr( $color_layout ).';
			}
			/*--------------------------------------------------------------
			# BACKGROUND COLORS
			--------------------------------------------------------------*/
			.backtotop,
			.features-list li:hover,
			.features-list li:last-child .feature-item,
			.yellow-overlay,
			.play-video:hover,
			span.menu-icon:hover .icon-bar,
			body.white-overlay span.menu-icon:hover .icon-bar,
			body.white-overlay .play-video:hover,
			body.white-overlay .site-header.is-sticky span.menu-icon:hover .icon-bar,
			.woocommerce nav.woocommerce-pagination ul li a:focus,
			.woocommerce nav.woocommerce-pagination ul li a:hover,
			.woocommerce nav.woocommerce-pagination ul li span.current {
				background-color: '.esc_attr( $color_layout ).';
			}
			/*--------------------------------------------------------------
			# BORDER COLORS
			--------------------------------------------------------------*/
			.separate,
			.pricing .column-wrapper:hover h4,
			form input:focus,
			form textarea:focus,
			.current-menu-item a,
			.main-navigation a:hover,
			.main-navigation a:focus,
			.woocommerce a.button:hover,
			.woocommerce a.added_to_cart:hover,
			.woocommerce nav.woocommerce-pagination ul,
			.woocommerce nav.woocommerce-pagination ul li,
			.woocommerce #respond input#submit.alt:hover,
			.woocommerce a.button.alt:hover,
			.woocommerce button.button.alt:hover,
			.woocommerce input.button.alt:hover {
				border-color: '.esc_attr( $color_layout ).';
			}
			';
		}

		$css .= $color_layout_css . $cusotm_header_style . $slider_opacity_css;
		wp_add_inline_style( 'business-center-pro-style', $css );
	}
endif;
add_action( 'wp_enqueue_scripts', 'business_center_pro_inline_css', 10 );


if ( ! function_exists( 'business_center_pro_add_inline_scripts' ) ) :
	function business_center_pro_add_inline_scripts() {
		$options = business_center_pro_get_theme_options();

		$fixed_menu_script = '';
		if ( $options['make_menu_sticky'] ) {
	   		$fixed_menu_script = '
	   			( function( $ ) {
	   				$(window).scroll(function(){
				        if ($(this).scrollTop() > 1)
				          $(".nav-shrink #masthead").addClass("is-sticky");
				        else
				          $(".nav-shrink #masthead").removeClass("is-sticky");
				    });
				} )( jQuery );';
		}
		$script = $fixed_menu_script;
	   	wp_add_inline_script( 'business-center-pro-custom', $script );
	}
endif;
add_action( 'wp_enqueue_scripts', 'business_center_pro_add_inline_scripts', 10 );