<?php
/**
 * Business Center Pro widgets inclusion
 *
 * This is the template that includes all custom widgets of Business Center Pro
 *
 * @package Theme Palace
 * @subpackage Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function business_center_pro_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Right Sidebar', 'business-center-pro' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'business-center-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Left Sidebar', 'business-center-pro' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Add widgets here.', 'business-center-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Search', 'business-center-pro' ),
		'id'            => 'business-center-pro-search',
		'description'   => esc_html__( 'This sidebar is only for the Search page.', 'business-center-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( '404', 'business-center-pro' ),
		'id'            => 'business-center-pro-404',
		'description'   => esc_html__( 'This sidebar is only for the 404 page.', 'business-center-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	for ($i=1; $i < 4; $i++) { 
		register_sidebar( array(
			'name'          => esc_html__( 'Footer ', 'business-center-pro' ).$i,
			'id'            => 'footer-'.$i,
			'description'   => esc_html__( 'Add footer widgets here.', 'business-center-pro' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );
	}
}
add_action( 'widgets_init', 'business_center_pro_widgets_init' );


/**
 * Include Social Link widget file
 */
require get_template_directory() . '/inc/widgets/social-link.php';

/**
 * Add Contact Info widget file
 */
require get_template_directory() . '/inc/widgets/contact-info.php';

/**
 * Add Featured Content widget file
 */
require get_template_directory() . '/inc/widgets/featured-content.php';

/**
 * Add popular post meta
 */
require get_template_directory() . '/inc/widgets/popular-post/popular-post-meta.php';

/**
 * Add popular post widget
 */
require get_template_directory() . '/inc/widgets/popular-post/popular-post-widget.php';

/**
 * Add popular post widget
 */
require get_template_directory() . '/inc/widgets/recent-posts.php';

/**
 * Add advertisement widget
 */
require get_template_directory() . '/inc/widgets/advertisement.php';

/**
 * Add featured image widget
 */
require get_template_directory() . '/inc/widgets/featured-image.php';

/**
 * Add newsletter widget
 */
require get_template_directory() . '/inc/widgets/newsletter.php';

/**
 * Register widgets
 */
add_action( 'widgets_init', function() {
	// Register Social Link widget
	register_widget( 'Business_Center_Pro_Social_Link' );

	// Register Custom Info widget
	register_widget( 'Business_Center_Pro_Contact_Info' );

	// Register Featured Content widget
	register_widget( 'Business_Center_Pro_Featured_Content' );

	// Register Popular Post widget
	register_widget( 'Business_Center_Pro_Popular_Post' );

	// Register Recent Post widget
	register_widget( 'Business_Center_Pro_Recent_Posts' );

	// Register Advertisement widget
	register_widget( 'Business_Center_Pro_Advertisement' );

	// Register Featured Image widget
	register_widget( 'Business_Center_Pro_Featured_Image' );

	// Register Newsletter widget
	register_widget( 'Business_Center_Pro_Newsletter' );
});
