<?php
/**
 * Template Name: Portfolio Template
 * The template for displaying portfolio pages.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Business Center Pro
 */

get_header(); ?>

    <section id="portfolio-gallery">
        <?php
            $categories_id = get_post_meta( $post->ID, 'business-center-pro-portfolio-template', true );

            if( empty( $categories_id ) ) : ?>
                <div id="primary" class="content-area">
                    <main id="main" class="site-main" role="main">
                        <?php get_template_part( 'template-parts/content', 'page' ); ?>
                    </main><!-- #main -->
                </div><!-- #primary -->
            <?php else : ?>
                <nav class="portfolio-filter">
                    <div class="container">
                        <ul>
                            <li><a href="#" data-filter="*" class="active"><?php esc_html_e( 'All','business-center-pro' ); ?></a></li>
                            <?php foreach ( $categories_id as $key => $category_id ) {
                            $category_object = get_category( $category_id );
                            echo '<li><a href="#" data-filter=".'. esc_attr( $category_object->slug ) .'">'. esc_html( $category_object->name ) .'</a></li>';
                            }
                        ?>
                        </ul>
                    </div><!-- .container -->
                </nav>
                <div id="gallery" class="page-section">
                    <div id="twocol" class="portfolio container">
                    <?php
                        $portfolio_args = array(
                            'category__in'   => $categories_id,
                            'posts_per_page' => absint( get_option( 'posts_per_page', 7 ) ), // Maximum number of posts to show on a page; set in Reading Options.,,
                        );

                        $portfolio_posts = get_posts( $portfolio_args );
                        if( !empty( $portfolio_posts ) ) :

                            $index = 1;

                            foreach ( $portfolio_posts as $key => $portfolio_post ) {
                                if( ( $index % 7  == 3 ) || ( $index % 7  == 0 ) ) {
                                    $item = 2;
                                }
                                else{
                                    $item = 1;
                                }

                                $portfolio_post_id = $portfolio_post->ID;

                                if ( has_post_thumbnail( $portfolio_post_id ) ) {
                                    $featured_img = wp_get_attachment_image_src( get_post_thumbnail_id( $portfolio_post->ID ), 'large' );
                                    $img_array = $featured_img[0];
                                } else {
                                    $img_array =  get_template_directory_uri() . '/assets/uploads/no-featured-image-1300x600.jpg';
                                }
                                if ( isset( $img_array ) ) {
                                  $post_image['img_array'][0] = $img_array;
                                }
                                $post_title        = get_the_title( $portfolio_post_id );
                                $post_url          = get_the_permalink( $portfolio_post_id );
                                $post_categories   = get_the_category( $portfolio_post_id );

                                $post_category_list = '';
                                $post_category_name = '';
                                foreach ( $post_categories as $key => $post_category ) {
                                    $post_category_name .= $post_category->name . ' ';
                                    $post_category_list .= $post_category->slug . ' ';
                                } ?>

                                <div class="portfolio-item item-w<?php echo esc_attr( $item ); ?> <?php echo esc_attr( $post_category_list ); ?> ">
                                    <div class="portfolio-featured-image" style="background-image:url( '<?php echo esc_url( $post_image['img_array'][0] ); ?>' );">
                                        <div class="portfolio-hover">
                                            <span class="item-category"></span><?php echo esc_html( $post_category_name ); ?></span>
                                            <span class="item-title"><a href="<?php echo esc_url( $post_url ); ?>"><?php echo esc_html( $post_title ); ?></a></span>
                                        </div><!-- .portfolio-hover -->
                                    </div><!-- .portfolio-featured-image -->
                                </div><!-- .portfolio-item -->
                            <?php $index++ ;}
                        endif; ?>
                    </div><!-- .portfolio -->
                    <div class="text-center">
                        <a href="#" id="loadmore" class="load-more btn btn-yellow"><?php esc_html_e( 'Load more', 'business-center-pro' ) ; ?></a>
                    </div><!-- .text-center -->
                </div><!-- #gallery -->
            <?php endif;?>
    </section><!-- #portfolio-gallery -->

<?php get_footer();
